@@ -1,9 +1,9 @@
 # with input in the DataFrame format
 # handle categorical values
+# update metadata of the dataset
 
 import rpi_feature_selection_toolbox
 import os, sys
-# from typing import NamedTuple, Union, List, Sequence, Any, Dict
 import typing
 import scipy.io
 import numpy as np
@@ -19,9 +19,6 @@ from d3m.primitive_interfaces.base import CallResult
 # from . import __version__
 
 
-#Inputs = container.ndarray
-#Outputs = container.ndarray
-
 Inputs = container.DataFrame
 Outputs = container.DataFrame
 
@@ -29,8 +26,6 @@ __all__ = ('IPCMBplus_Selector',)
 
 class Params(params.Params):
     pass
-#    n_features: int
-#    feature_index: ndarray
 
 
 class Hyperparams(hyperparams.Hyperparams):
@@ -64,7 +59,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-                'version': '2.2.2'
+                'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
@@ -119,12 +114,10 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         if self._training_inputs.any() == None or self._training_outputs.any() == None: 
             raise ValueError('Missing training data, or missing values exist.')
 
-        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
+        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})      
 
         a = rpi_feature_selection_toolbox.initialize()
         index = np.reshape(np.array(a.IPCMBplus()), [-1, ])
-        #index = np.reshape(np.array(a.IPCMBplus(dir_path)), [-1, ])
         self._index = (index - 1).astype(int)
         self._fitted = True
 
@@ -133,9 +126,11 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -168,7 +163,7 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
+	            'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIplus_Selector',
@@ -221,10 +216,8 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.JMIplus(dir_path)), [-1, ])
         index = np.reshape(np.array(a.JMIplus()), [-1, ])
 
         self._index = (index - 1).astype(int)
@@ -235,9 +228,11 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -270,7 +265,7 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
+	            'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.STMBplus_Selector',
@@ -322,15 +317,11 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         if self._training_inputs.any() == None or self._training_outputs.any() == None: 
             raise ValueError('Missing training data, or missing values exist.')
         
-        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
+        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})       
 
         a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.STMBplus(dir_path)), [-1, ])
         index = np.reshape(np.array(a.STMBplus()), [-1, ])
-        #print('\n')
-        #print(index)
-        #print('\n')
+        
         self._index = (index - 1).astype(int)
         self._fitted = True
 
@@ -339,9 +330,11 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -374,7 +367,7 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
+	            'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.aSTMBplus_Selector',
@@ -427,10 +420,8 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.aSTMBplus(dir_path)), [-1, ])
         index = np.reshape(np.array(a.aSTMBplus()), [-1, ])
 
         self._index = (index - 1).astype(int)
@@ -441,10 +432,11 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            #return CallResult(inputs[:, self._index])
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -477,7 +469,7 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
+	            'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.sSTMBplus_Selector',
@@ -530,10 +522,8 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.sSTMBplus(dir_path)), [-1, ])
         index = np.reshape(np.array(a.sSTMBplus()), [-1, ])
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -543,111 +533,11 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
-        else:
-            raise ValueError('Model should be fitted first.')
-
-
-    def get_params(self) -> None:
-        pass
-
-
-    def set_params(self) -> None:
-        pass
-
-
-
-class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
-
-    metadata = metadata_base.PrimitiveMetadata({
-        'id': '616e087e-1bc8-3884-8675-3420bce832d5',
-        'version': '2.1.3',
-        'name': 'pSTMB feature selector',
-        'keywords': ['rpi primitives'],
-        'source': {
-            'name': 'RPI'
-        },
-        'installation':[
-            {
-                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.3'
-            },
-            {
-                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
-            }
-        ],
-        'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.pSTMB_Selector',
-        'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
-        'primitive_family': 'FEATURE_SELECTION',
-    })
-
-
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
-        super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
-        self._index = None
-        self._training_inputs = None
-        self._training_outputs = None
-        self._fitted = False
-
-    def set_training_data(self, *, inputs: Inputs, outputs: Outputs) -> None:
-        # convert categorical values to numerical values for training labels
-        LE = preprocessing.LabelEncoder()
-        LE = LE.fit(outputs.iloc[:,0])
-        self._training_outputs = LE.transform(outputs.iloc[:,0])
-        
-        # convert cateforical values to numerical values in training data
-        metadata = inputs.metadata
-        [m,n] = inputs.shape
-        self._training_inputs = np.zeros((m,n))
-        for column_index in metadata.get_elements((metadata_base.ALL_ELEMENTS,)):
-            if column_index is metadata_base.ALL_ELEMENTS: 
-                continue
-            column_metadata = metadata.query((metadata_base.ALL_ELEMENTS, column_index))
-            semantic_types = column_metadata.get('semantic_types', [])
-            if 'https://metadata.datadrivendiscovery.org/types/CategoricalData' in semantic_types:
-                LE = preprocessing.LabelEncoder()
-                LE = LE.fit(inputs.iloc[:,column_index])
-                self._training_inputs[:,column_index] = LE.transform(inputs.iloc[:,column_index])  
-            else:
-                temp = list(inputs.iloc[:, column_index].as_matrix())
-                for i in np.arange(len(temp)):
-                    if bool(temp[i]):
-                        self._training_inputs[i,column_index] = float(temp[i])
-                    else:
-                        self._training_inputs[i,column_index] = 'nan'
-        self._fitted = False
-
-
-    def fit(self, *, timeout: float = None, iterations: int = None) -> None:
-        if self._fitted:
-            return CallResult(None)
-
-        if self._training_inputs.any() == None or self._training_outputs.any() == None: 
-            raise ValueError('Missing training data, or missing values exist.')
-
-        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
-
-        a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.pSTMB(dir_path)), [-1, ])
-        index = np.reshape(np.array(a.pSTMB()), [-1, ])
-
-        self._index = (index - 1).astype(int)
-        self._fitted = True
-
-        os.remove('rpi_data.mat')
-
-        return CallResult(None)
-
-
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
-        if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -679,7 +569,7 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
+	            'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_STMB_Selector',
@@ -732,10 +622,8 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.F_STMB(dir_path)), [-1, ])
         index = np.reshape(np.array(a.F_STMB()), [-1, ])
  
         self._index = (index - 1).astype(int)
@@ -746,9 +634,11 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -782,7 +672,7 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
+	            'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_aSTMB_Selector',
@@ -835,10 +725,8 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.F_aSTMB(dir_path)), [-1, ])
         index = np.reshape(np.array(a.F_aSTMB()), [-1, ])
 
         self._index = (index - 1).astype(int)
@@ -849,9 +737,11 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -884,7 +774,7 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
+	            'version': '2.2.3'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_sSTMB_Selector',
@@ -937,10 +827,8 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.F_sSTMB(dir_path)), [-1, ])
         index = np.reshape(np.array(a.F_sSTMB()), [-1, ])
 
         self._index = (index - 1).astype(int)
@@ -951,9 +839,11 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
         return CallResult(None)
 
 
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
+    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> base.CallResult[Outputs]:  # inputs: m x n numpy array
         if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
+            output = inputs.iloc[:, self._index]
+            output.metadata = inputs.metadata.clear(source=self, for_value=output, generate_metadata=True)
+            return CallResult(output)
         else:
             raise ValueError('Model should be fitted first.')
 
@@ -965,104 +855,3 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
     def set_params(self) -> None:
         pass
 
-
-
-class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
-
-    metadata = metadata_base.PrimitiveMetadata({
-        'id': 'd332d583-562f-374b-9737-d5d9c2208358',
-        'version': '2.1.3',
-        'name': 'JMIp feature selector',
-        'keywords': ['rpi primitives'],
-        'source': {
-            'name': 'RPI'
-        },
-        'installation':[
-            {
-                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'rpi_feature_selection_toolbox',
-                'version': '2.1.3'
-            },
-            {
-                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.2.2'
-            }
-        ],
-        'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIp_Selector',
-        'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
-        'primitive_family': 'FEATURE_SELECTION',
-    })
-
-
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
-        super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
-        self._index = None
-        self._training_inputs = None
-        self._training_outputs = None
-        self._fitted = False
-
-    def set_training_data(self, *, inputs: Inputs, outputs: Outputs) -> None:
-        # convert categorical values to numerical values for training labels
-        LE = preprocessing.LabelEncoder()
-        LE = LE.fit(outputs.iloc[:,0])
-        self._training_outputs = LE.transform(outputs.iloc[:,0])
-        
-        # convert cateforical values to numerical values in training data
-        metadata = inputs.metadata
-        [m,n] = inputs.shape
-        self._training_inputs = np.zeros((m,n))
-        for column_index in metadata.get_elements((metadata_base.ALL_ELEMENTS,)):
-            if column_index is metadata_base.ALL_ELEMENTS: 
-                continue
-            column_metadata = metadata.query((metadata_base.ALL_ELEMENTS, column_index))
-            semantic_types = column_metadata.get('semantic_types', [])
-            if 'https://metadata.datadrivendiscovery.org/types/CategoricalData' in semantic_types:
-                LE = preprocessing.LabelEncoder()
-                LE = LE.fit(inputs.iloc[:,column_index])
-                self._training_inputs[:,column_index] = LE.transform(inputs.iloc[:,column_index])  
-            else:
-                temp = list(inputs.iloc[:, column_index].as_matrix())
-                for i in np.arange(len(temp)):
-                    if bool(temp[i]):
-                        self._training_inputs[i,column_index] = float(temp[i])
-                    else:
-                        self._training_inputs[i,column_index] = 'nan'
-        self._fitted = False
-
-
-    def fit(self, *, timeout: float = None, iterations: int = None) -> None:
-        #if self._fitted:
-        #    return CallResult(None)
-
-        if self._training_inputs.any() == None or self._training_outputs.any() == None: 
-            raise ValueError('Missing training data, or missing values exist.')
-
-        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
-        #dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
-
-        a = rpi_feature_selection_toolbox.initialize()
-        #index = np.reshape(np.array(a.JMIp(dir_path)), [-1, ])
-        index = np.reshape(np.array(a.JMIp()), [-1, ])
-
-        self._index = (index - 1).astype(int)
-        self._fitted = True
-
-        os.remove('rpi_data.mat')
-
-        return CallResult(None)
-
-
-    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> Outputs:  # inputs: m x n numpy array
-        if self._fitted:
-            return CallResult(inputs.iloc[:, self._index])
-        else:
-            raise ValueError('Model should be fitted first.')
-
-
-    def get_params(self) -> None:
-        pass
-
-
-    def set_params(self) -> None:
-        pass
